@@ -477,11 +477,7 @@ QUrl DolphinSearchBox::balooUrlForSearching() const
     Baloo::Query query;
     query.addType(m_facetsWidget->facetType());
 
-    QStringList queryStrings;
-    QString ratingQuery = m_facetsWidget->ratingTerm();
-    if (!ratingQuery.isEmpty()) {
-        queryStrings << ratingQuery;
-    }
+    QStringList queryStrings = m_facetsWidget->searchTerms();
 
     if (m_contentButton->isChecked()) {
         queryStrings << text;
@@ -517,11 +513,17 @@ void DolphinSearchBox::updateFromQuery(const DolphinQuery& query)
 
     setText(query.text());
 
-    m_facetsWidget->resetOptions();
+    if (query.hasContentSearch()) {
+        m_contentButton->setChecked(true);
+    } else if (query.hasFileName())  {
+        m_fileNameButton->setChecked(true);
+    }
+
+    m_facetsWidget->resetSearchTerms();
     m_facetsWidget->setFacetType(query.type());
     const QStringList searchTerms = query.searchTerms();
     for (const QString& searchTerm : searchTerms) {
-        m_facetsWidget->setRatingTerm(searchTerm);
+        m_facetsWidget->setSearchTerm(searchTerm);
     }
 
     m_startSearchTimer->stop();
