@@ -68,7 +68,7 @@ ViewPropertiesDialog::ViewPropertiesDialog(DolphinView* dolphinView) :
     Q_ASSERT(dolphinView);
     const bool useGlobalViewProps = GeneralSettings::globalViewProps();
 
-    setWindowTitle(i18nc("@title:window", "View Properties"));
+    setWindowTitle(i18nc("@title:window", "View Display Style"));
 
     const QUrl& url = dolphinView->url();
     m_viewProps = new ViewProperties(url);
@@ -163,11 +163,23 @@ ViewPropertiesDialog::ViewPropertiesDialog(DolphinView* dolphinView) :
     layout->addRow(QString(), m_showInGroups);
     layout->addRow(QString(), m_showHiddenFiles);
 
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     connect(m_viewMode, QOverload<int>::of(&QComboBox::currentIndexChanged),
+#else
+    connect(m_viewMode, QOverload<int, const QString &>::of(&QComboBox::currentIndexChanged),
+#endif
             this, &ViewPropertiesDialog::slotViewModeChanged);
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     connect(m_sorting, QOverload<int>::of(&QComboBox::currentIndexChanged),
+#else
+    connect(m_sorting, QOverload<int, const QString &>::of(&QComboBox::currentIndexChanged),
+#endif
             this, &ViewPropertiesDialog::slotSortingChanged);
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     connect(m_sortOrder, QOverload<int>::of(&QComboBox::currentIndexChanged),
+#else
+    connect(m_sortOrder, QOverload<int, const QString &>::of(&QComboBox::currentIndexChanged),
+#endif
             this, &ViewPropertiesDialog::slotSortOrderChanged);
     connect(m_sortFoldersFirst, &QCheckBox::clicked,
             this, &ViewPropertiesDialog::slotSortFoldersFirstChanged);
